@@ -293,9 +293,9 @@ def boundaries(x, depth=None, kind=None):
     constant
     """
     if not isinstance(kind, dict):
-        kind = {i: kind for i in range(x.ndim)}
+        kind = dict.fromkeys(range(x.ndim), kind)
     if not isinstance(depth, dict):
-        depth = {i: depth for i in range(x.ndim)}
+        depth = dict.fromkeys(range(x.ndim), depth)
 
     for i in range(x.ndim):
         d = depth.get(i, 0)
@@ -368,6 +368,12 @@ def ensure_minimum_chunksize(size, chunks):
     return tuple(output)
 
 
+def _get_overlap_rechunked_chunks(x, depth2):
+    depths = [max(d) if isinstance(d, tuple) else d for d in depth2.values()]
+    # rechunk if new chunks are needed to fit depth in every chunk
+    return tuple(ensure_minimum_chunksize(size, c) for size, c in zip(depths, x.chunks))
+
+
 def overlap(x, depth, boundary, *, allow_rechunk=True):
     """Share boundaries between neighboring blocks
 
@@ -432,13 +438,12 @@ def overlap(x, depth, boundary, *, allow_rechunk=True):
     depths = [max(d) if isinstance(d, tuple) else d for d in depth2.values()]
     if allow_rechunk:
         # rechunk if new chunks are needed to fit depth in every chunk
-        new_chunks = tuple(
-            ensure_minimum_chunksize(size, c) for size, c in zip(depths, x.chunks)
-        )
-        x1 = x.rechunk(new_chunks)  # this is a no-op if x.chunks == new_chunks
+        x1 = x.rechunk(
+            _get_overlap_rechunked_chunks(x, depth2)
+        )  # this is a no-op if x.chunks == new_chunks
 
     else:
-        original_chunks_too_small = any([min(c) < d for d, c in zip(depths, x.chunks)])
+        original_chunks_too_small = any(min(c) < d for d, c in zip(depths, x.chunks))
         if original_chunks_too_small:
             raise ValueError(
                 "Overlap depth is larger than smallest chunksize.\n"
@@ -704,7 +709,7 @@ def map_overlap(
         _, args = unify_chunks(*list(concat(zip(args, inds))), warn=False)
 
     # Escape to map_blocks if depth is zero (a more efficient computation)
-    if all([all(depth_val == 0 for depth_val in d.values()) for d in depth]):
+    if all(all(depth_val == 0 for depth_val in d.values()) for d in depth):
         return map_blocks(func, *args, **kwargs)
 
     for i, x in enumerate(args):
@@ -721,7 +726,13 @@ def map_overlap(
 
     assert_int_chunksize(args)
     if not trim and "chunks" not in kwargs:
-        kwargs["chunks"] = args[0].chunks
+        if allow_rechunk:
+            # Adjust chunks based on the rechunking result
+            kwargs["chunks"] = _get_overlap_rechunked_chunks(
+                args[0], coerce_depth(args[0].ndim, depth[0])
+            )
+        else:
+            kwargs["chunks"] = args[0].chunks
     args = [
         overlap(x, depth=d, boundary=b, allow_rechunk=allow_rechunk)
         for x, d, b in zip(args, depth, boundary)
@@ -895,11 +906,6 @@ def push(array, n, axis):
     """
     import_optional_dependency("bottleneck", min_version="1.3.7")
 
-    def _fill_with_last_one(a, b):
-        # cumreduction apply the push func over all the blocks first so, the only missing part is filling
-        # the missing values using the last data of the previous chunk
-        return np.where(~np.isnan(b), b, a)
-
     if n is not None and 0 < n < array.shape[axis] - 1:
         arr = broadcast_to(
             arange(
@@ -926,6 +932,12 @@ def push(array, n, axis):
     )
 
 
+def _fill_with_last_one(a, b):
+    # cumreduction apply the push func over all the blocks first so, the only missing part is filling
+    # the missing values using the last data of the previous chunk
+    return np.where(~np.isnan(b), b, a)
+
+
 def _push(array, n: int | None = None, axis: int = -1):
     # work around for bottleneck 178
     limit = n if n is not None else array.shape[axis]
