@@ -1,6 +1,7 @@
 from __future__ import annotations
 
 import builtins
+import inspect
 import math
 import operator
 import warnings
@@ -542,7 +543,7 @@ def moment_agg(
             inner_term = np.abs(divide(totals, ns) - mu)
         else:
             inner_term = divide(totals, ns, dtype=dtype) - mu
-
+    inner_term = np.where(ns == 0, 0, inner_term)
     M = _moment_helper(Ms, ns, inner_term, order, sum, axis, kwargs)
 
     denominator = n.sum(axis=axis, **kwargs) - ddof
@@ -676,7 +677,7 @@ def nanvar(
             numel=nannumel,
             implicit_complex_dtype=implicit_complex_dtype,
         ),
-        partial(moment_agg, sum=np.nansum, ddof=ddof),
+        partial(moment_agg, sum=np.sum, ddof=ddof),
         axis=axis,
         keepdims=keepdims,
         dtype=dt,
@@ -1216,7 +1217,10 @@ def cumreduction(
     assert isinstance(axis, Integral)
     axis = validate_axis(axis, x.ndim)
 
-    m = x.map_blocks(func, axis=axis, dtype=dtype)
+    if "dtype" in inspect.signature(func).parameters:
+        m = x.map_blocks(partial(func, dtype=dtype), axis=axis, dtype=dtype)
+    else:
+        m = x.map_blocks(func, axis=axis, dtype=dtype)
 
     name = f"{func.__name__}-{tokenize(func, axis, binop, ident, x, dtype)}"
     n = x.numblocks[axis]
@@ -1564,7 +1568,7 @@ def quantile(
     and then calling ``numpy.quantile`` function across the remaining dimensions
     """
     if axis is None:
-        if any(n_blocks > 1 for n_blocks in a.numblocks):
+        if builtins.any(n_blocks > 1 for n_blocks in a.numblocks):
             raise NotImplementedError(
                 "The da.quantile function only works along an axis.  "
                 "The full algorithm is difficult to do in parallel"
@@ -1715,7 +1719,7 @@ def nanquantile(
     and then calling ``numpy.nanquantile`` function across the remaining dimensions
     """
     if axis is None:
-        if any(n_blocks > 1 for n_blocks in a.numblocks):
+        if builtins.any(n_blocks > 1 for n_blocks in a.numblocks):
             raise NotImplementedError(
                 "The da.nanquantile function only works along an axis.  "
                 "The full algorithm is difficult to do in parallel"
