@@ -32,7 +32,7 @@ from dask.array.creation import arange, diag, empty, indices, tri
 from dask.array.einsumfuncs import einsum  # noqa
 from dask.array.numpy_compat import NUMPY_GE_200
 from dask.array.reductions import reduction
-from dask.array.ufunc import multiply, sqrt
+from dask.array.ufunc import multiply, sqrt, true_divide
 from dask.array.utils import (
     array_safe,
     asarray_safe,
@@ -526,7 +526,7 @@ def apply_along_axis(func1d, axis, arr, *args, dtype=None, shape=None, **kwargs)
     # Adds other axes as needed.
     result = arr.map_blocks(
         _inner_apply_along_axis,
-        name=funcname(func1d) + "-along-axis",
+        token=funcname(func1d) + "-along-axis",
         dtype=dtype,
         chunks=(arr.chunks[:axis] + shape + arr.chunks[axis + 1 :]),
         drop_axis=axis,
@@ -1522,7 +1522,17 @@ def histogramdd(sample, bins, range=None, normed=None, weights=None, density=Non
 
 
 @derived_from(np)
-def cov(m, y=None, rowvar=1, bias=0, ddof=None):
+def cov(
+    m,
+    y=None,
+    rowvar=True,
+    bias=False,
+    ddof=None,
+    fweights=None,
+    aweights=None,
+    *,
+    dtype=None,
+):
     # This was copied almost verbatim from np.cov
     # See numpy license at https://github.com/numpy/numpy/blob/master/LICENSE.txt
     # or NUMPY_LICENSE.txt within this directory
@@ -1531,47 +1541,87 @@ def cov(m, y=None, rowvar=1, bias=0, ddof=None):
 
     # Handles complex arrays too
     m = asarray(m)
+
     if y is None:
-        dtype = np.result_type(m, np.float64)
+        dtype = result_type(m, np.float64)
     else:
         y = asarray(y)
-        dtype = np.result_type(m, y, np.float64)
+        dtype = result_type(m, y, np.float64)
+
+    if m.ndim > 2:
+        raise ValueError("m has more than 2 dimensions")
+    if y is not None and y.ndim > 2:
+        raise ValueError("y has more than 2 dimensions")
+
     X = array(m, ndmin=2, dtype=dtype)
 
-    if X.shape[0] == 1:
-        rowvar = 1
-    if rowvar:
-        N = X.shape[1]
-        axis = 0
-    else:
-        N = X.shape[0]
-        axis = 1
-
-    # check ddof
     if ddof is None:
-        if bias == 0:
-            ddof = 1
+        ddof = 1 if bias == 0 else 0
+
+    if not rowvar and m.ndim != 1:
+        X = X.T
+    if X.shape[0] == 0:
+        return array([]).reshape(0, 0)
+    if y is not None:
+        y = array(y, ndmin=2, dtype=dtype)
+        if not rowvar and y.shape[0] != 1:
+            y = y.T
+        X = concatenate((X, y), axis=0)
+
+    # Unlike NumPy, these checks don't include:
+    #    - if fweights are all integers
+    #    - if either fweights or aweights are all non-negative
+    # These checks potientially expensive for distributed arrays.
+    w = None
+    if fweights is not None:
+        fweights = asarray(fweights, dtype=float)
+        if fweights.ndim > 1:
+            raise RuntimeError("cannot handle multidimensional fweights")
+        if fweights.shape[0] != X.shape[1]:
+            raise RuntimeError("incompatible numbers of samples and fweights")
+        w = fweights
+    if aweights is not None:
+        aweights = asarray(aweights, dtype=float)
+        if aweights.ndim > 1:
+            raise RuntimeError("cannot handle multidimensional aweights")
+        if aweights.shape[0] != X.shape[1]:
+            raise RuntimeError("incompatible numbers of samples and aweights")
+        if w is None:
+            w = aweights
         else:
-            ddof = 0
-    fact = float(N - ddof)
+            w *= aweights
+
+    avg, w_sum = average(X, axis=1, weights=w, returned=True)
+    w_sum = w_sum[0]
+
+    # Determine the normalization
+    if w is None:
+        fact = X.shape[1] - ddof
+    elif ddof == 0:
+        fact = w_sum
+    elif aweights is None:
+        fact = w_sum - ddof
+    else:
+        fact = w_sum - ddof * sum(w * aweights) / w_sum
+
     if fact <= 0:
         warnings.warn("Degrees of freedom <= 0 for slice", RuntimeWarning)
         fact = 0.0
 
-    if y is not None:
-        y = array(y, ndmin=2, dtype=dtype)
-        X = concatenate((X, y), axis)
-
-    X = X - X.mean(axis=1 - axis, keepdims=True)
-    if not rowvar:
-        return (dot(X.T, X.conj()) / fact).squeeze()
+    X -= avg[:, None]
+    if w is None:
+        X_T = X.T
     else:
-        return (dot(X, X.T.conj()) / fact).squeeze()
+        X_T = (X * w).T
+    c = dot(X, X_T.conj())
+    c *= true_divide(1, fact)
+    return c.squeeze()
 
 
 @derived_from(np)
 def corrcoef(x, y=None, rowvar=1):
     c = cov(x, y, rowvar)
+
     if c.shape == ():
         return c / c
     d = diag(c)
@@ -2210,7 +2260,7 @@ def piecewise(x, condlist, funclist, *args, **kw):
         x,
         *condlist,
         dtype=x.dtype,
-        name="piecewise",
+        token="piecewise",
         funclist=funclist,
         func_args=args,
         func_kw=kw,
