@@ -19,7 +19,6 @@ import dask.bag as db
 from dask.base import (
     DaskMethodsMixin,
     clone_key,
-    collections_to_dsk,
     compute,
     compute_as_if_collection,
     get_collection_names,
@@ -68,19 +67,19 @@ def test_is_dask_collection():
 
 def test_is_dask_collection_dask_expr():
     pd = pytest.importorskip("pandas")
-    dx = pytest.importorskip("dask_expr")
+    dd = pytest.importorskip("dask.dataframe")
 
     df = pd.Series([1, 2, 3])
-    dxf = dx.from_pandas(df)
+    ddf = dd.from_pandas(df)
     assert not is_dask_collection(df)
-    assert is_dask_collection(dxf)
+    assert is_dask_collection(ddf)
 
 
 def test_is_dask_collection_dask_expr_does_not_materialize():
     pytest.importorskip("pandas")
-    dx = pytest.importorskip("dask_expr")
+    dx = pytest.importorskip("dask.dataframe.dask_expr")
 
-    class DoNotMaterialize(dx._core.Expr):
+    class DoNotMaterialize(dask._expr.Expr):
         @property
         def _meta(self):
             return 0
@@ -234,6 +233,7 @@ def test_replace_name_in_keys():
 class Tuple(DaskMethodsMixin):
     __slots__ = ("_dask", "_keys")
     __dask_scheduler__ = staticmethod(dask.threaded.get)
+    __dask_optimize__ = None
 
     def __init__(self, dsk, keys):
         self._dask = dsk
@@ -371,7 +371,7 @@ def test_compute_no_opt():
     # Otherwise, the lengths below would be 4 and 0.
     assert len([k for k in keys if "mul" in k[0]]) == 8
     assert len([k for k in keys if "add" in k[0]]) == 4
-    assert len([k for k in keys if "add-mul" in k[0]]) == 4  # See? Renamed
+    assert len([k for k in keys if "add-from_sequence-mul" in k[0]]) == 4
 
 
 @pytest.mark.skipif("not da")
@@ -429,7 +429,7 @@ def test_persist_dataframe():
     assert len(ddf1.__dask_graph__()) == 4
     ddf2 = ddf1.persist()
     assert isinstance(ddf2, dd.DataFrame)
-    assert len(ddf2.__dask_graph__()) == 2 if not dd._dask_expr_enabled() else 4
+    assert len(ddf2.__dask_graph__()) == 4
     dd.utils.assert_eq(ddf2, ddf1)
 
 
@@ -440,7 +440,7 @@ def test_persist_series():
     assert len(dds1.__dask_graph__()) == 4
     dds2 = dds1.persist()
     assert isinstance(dds2, dd.Series)
-    assert len(dds2.__dask_graph__()) == 2 if not dd._dask_expr_enabled() else 4
+    assert len(dds2.__dask_graph__()) == 4
     dd.utils.assert_eq(dds2, dds1)
 
 
@@ -450,74 +450,36 @@ def test_persist_scalar():
 
     ds = pd.Series([1, 2, 3, 4])
     dds1 = dd.from_pandas(ds, npartitions=2).min()
-    assert len(dds1.__dask_graph__()) == 5 if not dd._dask_expr_enabled() else 6
+    assert len(dds1.__dask_graph__()) == 5
     dds2 = dds1.persist()
-    if not dd._dask_expr_enabled():
-        assert isinstance(dds2, dd.core.Scalar)
-    assert len(dds2.__dask_graph__()) == 1 if not dd._dask_expr_enabled() else 2
+    assert isinstance(dds2, dd.Scalar)
+    assert len(dds2.__dask_graph__()) == 2
     dd.utils.assert_eq(dds2, dds1)
 
 
-@pytest.mark.skipif("not dd")
-def test_persist_dataframe_rename():
-    import dask.dataframe as dd
-
-    if dd._dask_expr_enabled():
-        pytest.skip("doesn't make sense")
-
-    df1 = pd.DataFrame({"a": [1, 2, 3, 4], "b": [5, 6, 7, 8]})
-    df2 = pd.DataFrame({"a": [2, 3, 5, 6], "b": [6, 7, 9, 10]})
-    ddf1 = dd.from_pandas(df1, npartitions=2)
-    rebuild, args = ddf1.__dask_postpersist__()
-    dsk = {("x", 0): df2.iloc[:2], ("x", 1): df2.iloc[2:]}
-    ddf2 = rebuild(dsk, *args, rename={ddf1._name: "x"})
-    assert ddf2.__dask_keys__() == [("x", 0), ("x", 1)]
-    dd.utils.assert_eq(ddf2, df2)
-
-
-@pytest.mark.skipif("not dd")
-def test_persist_series_rename():
-    import dask.dataframe as dd
-
-    if dd._dask_expr_enabled():
-        pytest.skip("doesn't make sense")
-
-    ds1 = pd.Series([1, 2, 3, 4])
-    ds2 = pd.Series([5, 6, 7, 8])
-    dds1 = dd.from_pandas(ds1, npartitions=2)
-    rebuild, args = dds1.__dask_postpersist__()
-    dsk = {("x", 0): ds2.iloc[:2], ("x", 1): ds2.iloc[2:]}
-    dds2 = rebuild(dsk, *args, rename={dds1._name: "x"})
-    assert dds2.__dask_keys__() == [("x", 0), ("x", 1)]
-    dd.utils.assert_eq(dds2, ds2)
-
-
-@pytest.mark.skipif("not dd")
-def test_persist_scalar_rename():
-    import dask.dataframe as dd
-
-    if dd._dask_expr_enabled():
-        pytest.skip("doesn't make sense")
-
-    ds1 = pd.Series([1, 2, 3, 4])
-    dds1 = dd.from_pandas(ds1, npartitions=2).min()
-    rebuild, args = dds1.__dask_postpersist__()
-    dds2 = rebuild({("x", 0): 5}, *args, rename={dds1._name: "x"})
-    assert dds2.__dask_keys__() == [("x", 0)]
-    dd.utils.assert_eq(dds2, 5)
-
-
 @pytest.mark.skipif("not dd or not da")
 def test_compute_array_dataframe():
     arr = np.arange(100).reshape((10, 10))
     darr = da.from_array(arr, chunks=(5, 5)) + 1
     df = pd.DataFrame({"a": [1, 2, 3, 4], "b": [5, 5, 3, 3]})
     ddf = dd.from_pandas(df, npartitions=2).a + 2
-    arr_out, df_out = compute(darr, ddf)
+    with pytest.warns(UserWarning, match="mixed.*materialize"):
+        arr_out, df_out = compute(darr, ddf)
     assert np.allclose(arr_out, arr + 1)
     dd.utils.assert_eq(df_out, df.a + 2)
 
 
+@pytest.mark.skipif("not dd")
+def test_compute_delayed_dataframe():
+    pdf = pd.DataFrame({"a": [1, 2, 3]})
+    df = dd.from_pandas(pdf, npartitions=1)
+    dl = delayed(lambda x: None)(pdf)
+    with pytest.warns(UserWarning, match="mixed.*materialize"):
+        df_out, dl_out = compute(df, dl)
+    assert dl_out is None
+    dd.utils.assert_eq(df_out, pdf)
+
+
 @pytest.mark.skipif("not dd")
 def test_compute_dataframe_valid_unicode_in_bytes():
     df = pd.DataFrame(data=np.random.random((3, 1)), columns=["ö".encode()])
@@ -527,7 +489,9 @@ def test_compute_dataframe_valid_unicode_in_bytes():
 @pytest.mark.skipif("not dd")
 def test_compute_dataframe_invalid_unicode():
     # see https://github.com/dask/dask/issues/2713
-    df = pd.DataFrame(data=np.random.random((3, 1)), columns=["\ud83d"])
+    df = pd.DataFrame(
+        data=np.random.random((3, 1)), columns=pd.Index(["\ud83d"], dtype="object")
+    )
     dd.from_pandas(df, npartitions=4)
 
 
@@ -656,16 +620,6 @@ def inc_to_dec(dsk, keys):
     return dsk
 
 
-def test_optimizations_keyword():
-    x = dask.delayed(inc)(1)
-    assert x.compute() == 2
-
-    with dask.config.set(optimizations=[inc_to_dec]):
-        assert x.compute() == 0
-
-    assert x.compute() == 2
-
-
 def test_optimize():
     x = dask.delayed(inc)(1)
     y = dask.delayed(inc)(x)
@@ -682,18 +636,6 @@ def test_optimize():
     # Computationally equivalent
     assert dask.compute(x2, y2, z2) == dask.compute(x, y, z)
 
-    # Applying optimizations before compute and during compute gives
-    # same results. Shows optimizations are occurring.
-    sols = dask.compute(x, y, z, optimizations=[inc_to_dec])
-    x3, y3, z3 = optimize(x, y, z, optimizations=[inc_to_dec])
-    assert dask.compute(x3, y3, z3) == sols
-
-    # Optimize respects global optimizations as well
-    with dask.config.set(optimizations=[inc_to_dec]):
-        x4, y4, z4 = optimize(x, y, z)
-    for a, b in zip([x3, y3, z3], [x4, y4, z4]):
-        assert dict(a.dask) == dict(b.dask)
-
 
 def test_optimize_nested():
     a = dask.delayed(inc)(1)
@@ -890,7 +832,10 @@ def test_optimize_globals():
     x = da.ones(10, chunks=(5,))
 
     def optimize_double(dsk, keys):
-        return {k: (mul, 2, v) for k, v in dsk.items()}
+        return {
+            k: (mul, 2, v) if not key_split(k).startswith("finalize") else v
+            for k, v in dsk.items()
+        }
 
     from dask.array.utils import assert_eq
 
@@ -916,7 +861,8 @@ def test_optimize_None():
     y = x[:9][1:8][::2] + 1  # normally these slices would be fused
 
     def my_get(dsk, keys):
-        assert dsk == dict(y.dask)  # but they aren't
+        # but they aren't. +1 for the finalize task
+        assert len(dsk.__dask_graph__()) == len(y.dask) + 1
         return dask.get(dsk, keys)
 
     with dask.config.set(array_optimize=None, scheduler=my_get):
@@ -925,7 +871,7 @@ def test_optimize_None():
 
 def test_scheduler_keyword():
     def schedule(dsk, keys, **kwargs):
-        return [[123]]
+        return [123]
 
     named_schedulers["foo"] = schedule
 
@@ -1000,17 +946,6 @@ def test_num_workers_config(scheduler):
     assert len(workers) == num_workers
 
 
-def test_optimizations_ctd():
-    pytest.importorskip("numpy")
-    da = pytest.importorskip("dask.array")
-    x = da.arange(2, chunks=1)[:1]
-    dsk1 = collections_to_dsk([x])
-    with dask.config.set({"optimizations": [lambda dsk, keys: dsk]}):
-        dsk2 = collections_to_dsk([x])
-
-    assert dsk1 == dsk2
-
-
 def test_clone_key():
     for key, seed in [("x", 123), (("x", 1), 456), (("sum-1-2-3", h1, 1), 123)]:
         validate_key(clone_key(key, seed))
@@ -1082,8 +1017,6 @@ def check_default_scheduler(module, collection, expected, emscripten):
 @pytest.mark.parametrize(
     "params",
     (
-        "'dask.dataframe', '_Frame', 'sync', True",
-        "'dask.dataframe', '_Frame', 'threads', False",
         "'dask.array', 'Array', 'sync', True",
         "'dask.array', 'Array', 'threads', False",
         "'dask.bag', 'Bag', 'sync', True",
@@ -1094,9 +1027,6 @@ def test_emscripten_default_scheduler(params):
     pytest.importorskip("numpy")
     pytest.importorskip("dask.array")
     pytest.importorskip("pandas")
-    dd = pytest.importorskip("dask.dataframe")
-    if dd._dask_expr_enabled() and "dask.dataframe" in params:
-        pytest.skip("objects not available")
     proc = subprocess.run(
         [
             sys.executable,
