@@ -10,14 +10,17 @@ import random
 import subprocess
 import sys
 import textwrap
+from concurrent.futures import ThreadPoolExecutor
 from enum import Enum, Flag, IntEnum, IntFlag
 from typing import Union
 
 import cloudpickle
 import pytest
+from packaging.version import Version
 from tlz import compose, curry, partial
 
 import dask
+from dask._compatibility import PY_VERSION
 from dask.core import flatten, literal
 from dask.tokenize import TokenizationError, normalize_token, tokenize
 from dask.utils import tmpfile
@@ -567,17 +570,34 @@ def test_tokenize_pandas():
     a = pd.DataFrame({"x": [1, 2, 3], "y": ["a", "b", "a"]})
     b = pd.DataFrame({"x": [1, 2, 3], "y": ["a", "b", "a"]})
     a["z"] = a.y.astype("category")
+
+    # tokenize is currently sensitive to fragmentation of the pyarrow Array
+    # backing the columns. Create a new one to work around this.
+    a.columns = pd.Index(["x", "y", "z"])
     assert check_tokenize(a) != check_tokenize(b)
     b["z"] = a.y.astype("category")
+
+    b.columns = pd.Index(["x", "y", "z"])
     assert check_tokenize(a) == check_tokenize(b)
 
 
+@pytest.mark.skipif("not pd")
+def test_tokenize_pandas_fragmented_index():
+    s = pd.concat([pd.Series(1, index=["a", "b"]), pd.Series(2, index=["c", "d"])])
+    check_tokenize(s)
+
+
 @pytest.mark.skipif("not pd")
 def test_tokenize_pandas_invalid_unicode():
     # see https://github.com/dask/dask/issues/2713
     df = pd.DataFrame(
-        {"x\ud83d": [1, 2, 3], "y\ud83d": ["4", "asd\ud83d", None]}, index=[1, 2, 3]
+        {
+            "x": [1, 2, 3],
+            "y": pd.Series(["4", "asd\ud83d", None], dtype="object"),
+        },
+        index=[1, 2, 3],
     )
+    df.columns = pd.Index(["x\ud83d", "y\ud83d"], dtype="object")
     check_tokenize(df)
 
 
@@ -845,6 +865,7 @@ def test_nested_tokenize_seen():
 
 def test_tokenize_dict():
     # Insertion order is ignored. Keys can be an unsortable mix of types.
+    assert check_tokenize({"x": 1, 1: "x"}) == "ba2498a4c5583cc3ec540865185cdafd"
     assert check_tokenize({"x": 1, 1: "x"}) == check_tokenize({1: "x", "x": 1})
     assert check_tokenize({"x": 1, 1: "x"}) != check_tokenize({"x": 1, 2: "x"})
     assert check_tokenize({"x": 1, 1: "x"}) != check_tokenize({"x": 2, 1: "x"})
@@ -954,6 +975,9 @@ def test_local_objects():
     assert check_tokenize(LocalDaskTokenize()) != check_tokenize(LocalReducible())
 
 
+@pytest.mark.skipif(
+    PY_VERSION >= Version("3.13"), reason="https://github.com/dask/dask/issues/11457"
+)
 def test_tokenize_dataclass():
     a1 = ADataClass(1)
     a2 = ADataClass(2)
@@ -1198,6 +1222,18 @@ def test_tokenize_functions_main():
         return y + 1
 
     assert tokenize(inc2) != tokenize(inc)
+
+    # Test that redefining a function changes the token
+    def func(x):
+        return x + 1
+
+    result = tokenize(func)
+
+    def func(x):
+        return x + 2
+
+    result2 = tokenize(func)
+    assert result != result2
     """
     proc = subprocess.run([sys.executable, "-c", textwrap.dedent(script)])
     proc.check_returncode()
@@ -1434,6 +1470,23 @@ def test_tokenize_pandas_arrow_strings():
     assert any(str(tok) == "string" for tok in flatten(tokens))
 
 
+class APickleable:
+    counter = 0
+
+    def __reduce__(self):
+        APickleable.counter += 1
+        return APickleable, ()
+
+
+def test_normalize_pickle():
+    a = APickleable()
+    tokenize(a)
+    # We're pickling multiple times because pickle is caching things on
+    # instances such that subsequent pickles can yield different results.
+    # For a trivial object like this, this should only happen twice
+    assert APickleable.counter <= 2
+
+
 def test_tokenize_recursive_respects_ensure_deterministic():
     class Foo:
         def __dask_tokenize__(self):
@@ -1441,3 +1494,60 @@ def test_tokenize_recursive_respects_ensure_deterministic():
 
     with pytest.raises(RuntimeError):
         tokenize(Foo(), ensure_deterministic=True)
+
+
+def test_tokenize_nested_sequence_thread_safe():
+    nested_list = []
+    for ix in range(100):
+        nested_list = [ix, nested_list]
+
+    nested_dict = {}
+    for ix in range(50):
+        nested_dict = {ix: nested_dict}
+
+    normalize_token(nested_list)
+    with ThreadPoolExecutor() as pool:
+        futures = [pool.submit(normalize_token, nested_list) for _ in range(1000)]
+        assert len({f.result() for f in futures}) == 1
+        futures = [pool.submit(normalize_token, nested_dict) for _ in range(1000)]
+        assert len({f.result() for f in futures}) == 1
+
+
+def test_tokenize_range_index():
+    np = pytest.importorskip("numpy")
+    pd = pytest.importorskip("pandas")
+    a = pd.RangeIndex(0, 10)
+    b = pd.RangeIndex(0, 10)
+    c = pd.RangeIndex(0, 20)
+    assert check_tokenize(a) == check_tokenize(b)
+    assert check_tokenize(a) != check_tokenize(c)
+
+    d = pd.RangeIndex(0, 10, step=2)
+    e = pd.RangeIndex(0, 10, step=3)
+    assert check_tokenize(d) != check_tokenize(e)
+
+    large = pd.RangeIndex(0, 1000000)
+    array_token = normalize_token(np.zeros(10))
+    assert isinstance(array_token[0], str)
+    # hex_buffer_output_len
+    # It's difficult to assert what actually goes into the tokens
+    # Therefore we just check if there is a string of the appropriate length in
+    # the tokens below This check is to verify the assumption and to avoid hard
+    # coding a length. This seems to not be stable across python versions or
+    # platforms but there is a minimal length
+    hex_hash_len = len(array_token[0])
+    assert hex_hash_len >= 32
+
+    def assert_no_hashes(tokens):
+        if isinstance(tokens, (list, tuple)):
+            for token in tokens:
+                assert_no_hashes(token)
+        elif isinstance(tokens, dict):
+            for key, value in tokens.items():
+                assert_no_hashes(key)
+                assert_no_hashes(value)
+        elif isinstance(tokens, str):
+            if len(tokens) == hex_hash_len:
+                raise AssertionError("found a hash")
+
+    assert_no_hashes(normalize_token(large))
